@@ -8,7 +8,7 @@ use parent 'Tesla::API';
 use Carp qw(croak confess);
 use Data::Dumper;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use constant {
     DEBUG_ONLINE    => 0,
@@ -371,7 +371,7 @@ sub doors_lock {
     $self->api_cache_clear;
 
     if (! $return->{result} && $self->warn) {
-        print "Couldn't unlock the doors: '$return->{reason}'\n";
+        print "Couldn't lock the doors: '$return->{reason}'\n";
     }
 
     return $return->{result};
@@ -599,12 +599,21 @@ Tesla::Vehicle - Access information and command Tesla automobiles via the API
 
 This distribution provides methods for accessing and updating aspects of your
 Tesla vehicle. Not all attributes available through Tesla's API have methods
-listed here yet, I'm only starting with the ones I use myself; I will add more
-as I go.
+listed here yet, but more will be added as time goes on.
 
-For now, you can use the L<Tesla::API> distribution to write your own accessors
-that aren't complete here. (This distribution uses that module for all Tesla
-API access).
+To access attributes that we don't have methods for, see the
+L</AGGREGATE DATA METHODS> section, pull that data, then extract out the info
+you want. If we don't have an aggregate data method for something you want yet,
+see L<Tesla::API> to be able to get this yourself.
+
+As always, requests for updates to my software is encouraged. Please just open
+an L<issue|https://github.com/stevieb9/tesla-vehicle/issues>.
+
+=head1 IMPORTANT
+
+The parent module L<Tesla::API> that we inherit the Tesla API access code from
+has a complex caching mechanism in place that you ought to know about. Please do
+read through the L<Tesla API Caching|Tesla::API/API CACHING> documentation.
 
 =head1 OBJECT MANAGEMENT METHODS
 
@@ -638,7 +647,7 @@ You can set this after instantiation by a call to C<auto_wake()>.
 
 I<Default>: False.
 
-    delay
+    api_cache_time
 
 I<Optional, Integer>: The number of seconds to cache data returned from Tesla's
 API.
@@ -680,28 +689,6 @@ I<Optional, Bool>: True (C<1>) to enable, false (C<0>) to disable the warnings.
 
 I<Default>: True
 
-=head1 VEHICLE SUMMARY METHODS
-
-=head2 in_service
-
-Returns a bool whether your vehicle is in service mode or not.
-
-=head2 option_codes
-
-Returns a comma-delimited list of option codes of the options that are enabled
-on your vehicle.
-
-=head2 vehicle_id
-
-Returns an integer of Tesla's representation of the vehicle identification of
-your vehicle. This is not the same as the ID you use to access the API.
-
-=head2 vin
-
-Returns an alpha-numeric string that contains the actual Vehicle Identification
-Number of your vehicle. This value is located on a stamped plate on the driver's
-side bottom on the outside of your windshield.
-
 =head1 VEHICLE IDENTIFICATION METHODS
 
 =head2 id($id)
@@ -718,7 +705,7 @@ one. This can be set as a parameter in C<new()>. If you attempt an API call that
 requires and ID and one isn't set, we C<croak()>.
 
 If you only have a single Tesla vehicle registered under your account, we will
-set C<my_vehicle_id()> to that ID when you instantiate the object.
+set C<id()> to that ID when you instantiate the object.
 
 You can also have this auto-populated in C<new()> by sending it in with the
 C<< id => $id >> parameter.
@@ -746,6 +733,28 @@ Example:
         1234567891012 => "Steve's Model S",
     }
 
+=head1 VEHICLE SUMMARY METHODS
+
+=head2 in_service
+
+Returns a bool whether your vehicle is in service mode or not.
+
+=head2 option_codes
+
+Returns a comma-delimited string of option codes of the options that are enabled
+on your vehicle.
+
+=head2 vehicle_id
+
+Returns an integer of Tesla's representation of the vehicle identification of
+your vehicle. This is not the same as the ID you use to access the API.
+
+=head2 vin
+
+Returns an alpha-numeric string that contains the actual Vehicle Identification
+Number of your vehicle. This value is located on a stamped plate on the driver's
+side bottom on the outside of your windshield.
+
 =head1 COMMAND METHODS
 
 All command methods return a true value (C<1>)if the operation was successful,
